%% Observability
clear all
close all

%% Impliment values
scale = 1e5; % Scaling to prevent stiff system

beta = 1.05e9/scale; % Bulk modulus for Benzene [Bar]
a = pi*0.0254^2; % Cross-section of the pipeline [m^2]
density = 900; % Density of fluid [kg/m^3]
l = 14; % Length of pipesegment [m] 

k1 = beta/(a*l*scale); % Simplifcation to the code with scaling
k2 = (a*scale)/(l*density);
d = 1; % Friction factor for pipe roughness coefficient

n = 22; % Number of states, half pressure, half flow

An = zeros(n,n); % Making an A mastrix with n by n dimension of zeros
p = n/2+1;
 for m = 1:n/2-1 % Adding k1 and -k2*d to the state-space model
     An(m,p) = k1;
     An(m,p+1) = -k1;
     An(p,p) = -d;
     p = p+1;
 end 
An(n/2,n) = k1; % Adding k1 to qN
An(n/2+1,1) = -k2;    % Adding -k2 to p1
An(n,n) = -d;
p = 1;
 for m = n/2+2:n % Adding k2 from 2 to n-1
     An(m,p) = k2;
     An(m,p+1) = -k2;
     p = p+1;
 end 

Cn = zeros(n,n);  % Making a C matrix for pressure
Cn(1,1) = 1; 
Cn(n/2,n/2) = 1; % Adding measurement points

Bn = zeros(n,2);% Creating the B matrix
Bn(n/2,2) = -k1;
Bn(n/2+1,1) = k2;


%% Inital values 
p_in = (75*1e5)/scale; % u1 in [Bar]
q_out = 2*a; % Cross-section * 2 m/s [m^3/s]
u = [p_in;q_out]; % u for B matrix

C_estimation = Cn; % Make it easier

Q = 1e-3; % Process noise covariance
R = 1e-4; % Measurement noise covariance
Ts = 0.1; % Sampling time [s]
P_ = Q*diag(ones(n,1)); % Guessed error covariance
x_hat_ = zeros(n,1); % Estimated values set to 0

SimTime = 10000; % Simulation time
filename = 'KalmanValues.mat'; % Filename for saving data
SimFile = 'KalmanFilter'; % Simulink file

%% Smaller cross-section at control volume, wax thickness 0.5 mm
a_05 = pi*0.0249^2; % Cross-section of the section with 0.5mm wax thickness [m^2]
k1_a_05 = beta/(a_05*l*scale); % New k1 value with 0.5mm wax thickness
k2_a_05 = (scale*a_05)/(l*density); % New k2 value with 0.5mm wax thickness

for m = 0:n/2
    A_estimation = An; % Copy of state-space equation
    B_estimation = Bn; % Copy of state-space equation
    if m == 1
        A_estimation(1,n/2+1) = k1_a_05; 
        A_estimation(1,n/2+2) = -k1_a_05;
        A_estimation(n/2+1,1) = -k2_a_05;
        B_estimation(n/2+1,1) = k2_a_05;
    elseif m == n/2
        A_estimation(m,n) = k1_a_05;
        A_estimation(n,n/2) = -k2_a_05;
        A_estimation(n,n/2-1) = k2_a_05;
        B_estimation(n/2,2) = -k1_a_05;
    elseif m == 0
        A_estimation = An;
        B_estimation = Bn;
    else
        A_estimation(m,n/2+m) = k1_a_05;
        A_estimation(m,n/2+1+m) = -k1_a_05;
        A_estimation(n/2+m,m-1) = k2_a_05;
        A_estimation(n/2+m,m) = -k2_a_05;
    end
    
    [A_d,B_d] = c2d(A_estimation,B_estimation,Ts); % Discrete A and B
    C_d = C_estimation; % Discrete C

    obser_estimation = obsv(A_estimation,C_estimation); % Caluclating the Observability matrix
    rank_estimation = rank(obser_estimation); % The rank of Observability matrix 
    fprintf('%d. control volume, %d states. Rank of Observability matrix %d.\n',m,n,rank_estimation)
    stable = eig(A_estimation) % See if the A matrix is stable
    
%% Starting the simulation
    KalmanData = struct('A',A_d,'B',B_d,'C',C_d,'x',x_hat_,'P',P_,'Q',Q,'R',R); % Making a struct to impliment in the Kalman fiter with in SIMULINK
    simOut = sim(SimFile,SimTime); % Simulate in SIMULINK
%% Saving the values
    esti_value = simOut.get('esti');
    esti_value = esti_value.data;
    eval(['estimated_' num2str(m) '= esti_value(1:round(end/100):end,1:11)']);
    save(filename,['estimated_' num2str(m)],'-append');    
end


%% Smaller cross-section at control volume, wax thickness 1 mm
a_1 = pi*0.0245^2; % Cross-section of the section with 1mm wax thickness [m^2]
k1_a_1 = beta/(a_1*l*scale); % New k1 value with 0.5mm wax thickness
k2_a_1 = (scale*a_1)/(l*density); % New k2 value with 0.5mm wax thickness

for o = 1:n/2
    A_estimation = An; % Copy of state-space equation
    B_estimation = Bn; % Copy of state-space equation
    if o == 1
        A_estimation(1,n/2+1) = k1_a_1;
        A_estimation(1,n/2+2) = -k1_a_1;
        A_estimation(n/2+1,1) = -k2_a_1;
        B_estimation(n/2+1,1) = k2_a_1;
    elseif o == n/2
        A_estimation(o,n) = k1_a_1;
        A_estimation(n,n/2) = -k2_a_1;
        A_estimation(n,n/2-1) = k2_a_1;
        B_estimation(n/2,2) = -k1_a_1;
    else
        A_estimation(o,n/2+o) = k1_a_1;
        A_estimation(o,n/2+1+o) = -k1_a_1;
        A_estimation(n/2+o,o-1) = k2_a_1;
        A_estimation(n/2+o,o) = -k2_a_1;
    end
    
    [A_d,B_d] = c2d(A_estimation,B_estimation,Ts); % Discrete A and B
    C_d = C_estimation; % Discrete C
    
    obser_estimation = obsv(A_estimation,C_estimation); % Caluclating the Observability matrix
    rank_estimation = rank(obser_estimation); % The rank of Observability matrix 
    fprintf('%d. control volume, %d states. Rank of Observability matrix %d.\n',o,n,rank_estimation)
    stable = eig(A_estimation) % See if the A matrix is stable
    
%% Starting the simulation
    KalmanData = struct('A',A_d,'B',B_d,'C',C_d,'x',x_hat_,'P',P_,'Q',Q,'R',R); % Making a struct to impliment in the Kalman fiter with in SIMULINK
    simOut = sim(SimFile,SimTime); % Simulate in SIMULINK
%% Saving the values
    esti_value = simOut.get('esti');
    esti_value = esti_value.data;
    eval(['estimated_' num2str(n/2+o) '= esti_value(1:round(end/100):end,1:11)']);
    save(filename,['estimated_' num2str(n/2+o)],'-append');
end