%% COMSOL and estimation plots
clear all
close all

Pressure_COMSOL_waxmid = load('waxmid.dat');
Pressure_COMSOL_waxstart = load('waxstart.dat');
Pressure_COMSOL_waxend = load('waxend.dat');

Pressure_estimate = load('KalmanValues.mat');

%% wax = 1 mm @ 50m 
t_r1_50m = [0 5e3 1e4];
y_r1_50m = [Pressure_COMSOL_waxstart(1914,2) Pressure_COMSOL_waxstart(7856,2) Pressure_COMSOL_waxstart(13798,2)]/1e5;

t_hat_r1_50m_15 = 0:100:10000;
hat_r1_50m_15_15 = Pressure_estimate.estimated_15(:,4);
hat_r1_50m_15_14 = Pressure_estimate.estimated_15(:,3);
hat_r1_50m_15_16 = Pressure_estimate.estimated_15(:,5);

fig50m1mm = figure('Name','COMSOL values waxstart 1mm','Color','White');
subplot(2,1,1)
plot(t_r1_50m,y_r1_50m,'b','LineWidth',2)
hold on
plot(t_hat_r1_50m_15,hat_r1_50m_15_15,'r','LineWidth',2)
plot(t_hat_r1_50m_15,hat_r1_50m_15_14,'y-.','LineWidth',2)
plot(t_hat_r1_50m_15,hat_r1_50m_15_16,'g-.','LineWidth',2)
xlabel('Time [s]'); ylabel('Pressure [Bar]')
legend('COMSOL simulation','Estimated nearest control volume','Estimated left of nearest control volume','Estimated right of nearest control volume','location','southeast')
title('Estimated vs. simulated pressure, 1 mm wax deposition at 50 m.')
subplot(2,1,2)
plot(t_r1_50m,y_r1_50m*1e5,'b','LineWidth',2)
hold on
plot(t_hat_r1_50m_15,hat_r1_50m_15_15*1e5,'r','LineWidth',2)
plot(t_hat_r1_50m_15,hat_r1_50m_15_14*1e5,'y-.','LineWidth',2)
plot(t_hat_r1_50m_15,hat_r1_50m_15_16*1e5,'g-.','LineWidth',2)
xlim([9900 10000])
ylim([73.88 73.92]*1e5)
xlabel('Time [s]'); ylabel('Pressure [Pa]')

%% wax = 0.5 mm @ 50m
t_r05_50m = [0 5e3 1e4];
y_r05_50m = [Pressure_COMSOL_waxstart(20390,2) Pressure_COMSOL_waxstart(27416,2) Pressure_COMSOL_waxstart(34442,2)]/1e5;

t_hat_r05_50m_4 = 0:100:10000;
hat_r05_50m_4_4 = Pressure_estimate.estimated_4(:,4);
hat_r05_50m_4_3 = Pressure_estimate.estimated_4(:,3);
hat_r05_50m_4_5 = Pressure_estimate.estimated_4(:,5);

fig50m05mm = figure('Name','COMSOL values waxstart 0.5mm','Color','White');
subplot(2,1,1)
plot(t_r05_50m,y_r05_50m,'b','LineWidth',2)
hold on
plot(t_hat_r05_50m_4,hat_r05_50m_4_4,'r','LineWidth',2)
plot(t_hat_r05_50m_4,hat_r05_50m_4_3,'y-.','LineWidth',2)
plot(t_hat_r05_50m_4,hat_r05_50m_4_5,'g-.','LineWidth',2)
xlabel('Time [s]'); ylabel('Pressure [Bar]')
title('Estimated vs. simulated pressure, 0.5 mm wax deposition at 50 m.')
legend('COMSOL simulation','Estimated nearest control volume','Estimated left of nearest control volume','Estimated right of nearest control volume','location','southeast')
subplot(2,1,2)
plot(t_r05_50m,y_r05_50m*1e5,'b','LineWidth',2)
hold on
plot(t_hat_r05_50m_4,hat_r05_50m_4_4*1e5,'r','LineWidth',2)
plot(t_hat_r05_50m_4,hat_r05_50m_4_3*1e5,'y-.','LineWidth',2)
plot(t_hat_r05_50m_4,hat_r05_50m_4_5*1e5,'g-.','LineWidth',2)
xlim([9900 10000])
ylim([73.9 73.96]*1e5)
xlabel('Time [s]'); ylabel('Pressure [Pa]')

%% wax = 1 mm @ 75 m 
t_r1_75m = [0 5e3 1e4];
y_r1_75m = [Pressure_COMSOL_waxmid(3200,2) Pressure_COMSOL_waxmid(9569,2) Pressure_COMSOL_waxmid(15938,2)]/1e5;

t_hat_r1_75m_17 = 0:100:10000;
hat_r1_75m_17_17 = Pressure_estimate.estimated_17(:,6);
hat_r1_75m_17_16 = Pressure_estimate.estimated_17(:,5);
hat_r1_75m_17_18 = Pressure_estimate.estimated_17(:,7);

fig75m1mm = figure('Name','COMSOL values waxmid 1mm','Color','White');
subplot(2,1,1)
plot(t_r1_75m,y_r1_75m,'b','LineWidth',2)
hold on
plot(t_hat_r1_75m_17,hat_r1_75m_17_17,'r','LineWidth',2)
plot(t_hat_r1_75m_17,hat_r1_75m_17_16,'y-.','LineWidth',2)
plot(t_hat_r1_75m_17,hat_r1_75m_17_18,'g-.','LineWidth',2)
xlabel('Time [s]'); ylabel('Pressure [Bar]')
legend('COMSOL simulation','Estimated nearest control volume','Estimated left of nearest control volume','Estimated right of nearest control volume','location','southeast')
title('Estimated vs. simulated pressure, 1 mm wax deposition at 75 m.')
subplot(2,1,2)
plot(t_r1_75m,y_r1_75m*1e5,'b','LineWidth',2)
hold on
plot(t_hat_r1_75m_17,hat_r1_75m_17_17*1e5,'r','LineWidth',2)
plot(t_hat_r1_75m_17,hat_r1_75m_17_16*1e5,'y-.','LineWidth',2)
plot(t_hat_r1_75m_17,hat_r1_75m_17_18*1e5,'g-.','LineWidth',2)
xlim([9900 10000])
ylim([73.35 73.5]*1e5)
xlabel('Time [s]'); ylabel('Pressure [Pa]')

%% wax = 0.5 mm @ 75 m
t_r05_75m = [0 5e3 1e4];
y_r05_75m = [Pressure_COMSOL_waxmid(22334,2) Pressure_COMSOL_waxmid(28859,2) Pressure_COMSOL_waxmid(35384,2)]/1e5;

t_hat_r05_75m_6 = 0:100:10000;
hat_r05_75m_6_6 = Pressure_estimate.estimated_6(:,6);
hat_r05_75m_6_5 = Pressure_estimate.estimated_6(:,5);
hat_r05_75m_6_7 = Pressure_estimate.estimated_6(:,7);

fig75m05mm = figure('Name','COMSOL values waxmid 0.5mm','Color','White');
subplot(2,1,1)
plot(t_r05_75m,y_r05_75m,'b','LineWidth',2)
hold on
plot(t_hat_r05_75m_6,hat_r05_75m_6_6,'r','LineWidth',2)
plot(t_hat_r05_75m_6,hat_r05_75m_6_5,'y-.','LineWidth',2)
plot(t_hat_r05_75m_6,hat_r05_75m_6_7,'g-.','LineWidth',2)
xlabel('Time [s]'); ylabel('Pressure [Bar]')
legend('COMSOL simulation','Estimated nearest control volume','Estimated left of nearest control volume','Estimated right of nearest control volume','location','southeast')
title('Estimated vs. simulated pressure, 0.5 mm wax deposition at 75 m.')
subplot(2,1,2)
plot(t_r05_75m,y_r05_75m*1e5,'b','LineWidth',2)
hold on
plot(t_hat_r05_75m_6,hat_r05_75m_6_6*1e5,'r','LineWidth',2)
plot(t_hat_r05_75m_6,hat_r05_75m_6_5*1e5,'y-.','LineWidth',2)
plot(t_hat_r05_75m_6,hat_r05_75m_6_7*1e5,'g-.','LineWidth',2)
xlim([9900 10000])
ylim([73.35 73.5]*1e5)
xlabel('Time [s]'); ylabel('Pressure [Pa]')

%% wax = 1 mm @ 100m 
t_r1_100m = [0 5e3 1e4];
y_r1_100m = [Pressure_COMSOL_waxend(4029,2) Pressure_COMSOL_waxend(9971,2) Pressure_COMSOL_waxend(15913,2)]/1e5;

t_hat_r1_100m_19 = 0:100:10000;
hat_r1_100m_19_8 = Pressure_estimate.estimated_19(:,8);
hat_r1_100m_19_7 = Pressure_estimate.estimated_19(:,7);
hat_r1_100m_19_9 = Pressure_estimate.estimated_19(:,9);

fig100m1mm = figure('Name','COMSOL values waxend 1mm','Color','White');
subplot(2,1,1)
plot(t_r1_100m,y_r1_100m,'b','LineWidth',2)
hold on
plot(t_hat_r1_100m_19,hat_r1_100m_19_8,'r','LineWidth',2)
plot(t_hat_r1_100m_19,hat_r1_100m_19_7,'y-.','LineWidth',1.5)
plot(t_hat_r1_100m_19,hat_r1_100m_19_9,'g-.','LineWidth',1.5)
xlabel('Time [s]'); ylabel('Pressure [Bar]')
legend('COMSOL simulation','Estimated at control volume','Estimated left of nearest control volume','Estimated right of nearest control volume','location','southeast')
title('Estimated vs. simulated pressure, 1 mm wax deposition at 100 m.')
subplot(2,1,2)
plot(t_r1_100m,y_r1_100m*1e5,'b','LineWidth',2)
hold on
plot(t_hat_r1_100m_19,hat_r1_100m_19_8*1e5,'r','LineWidth',2)
plot(t_hat_r1_100m_19,hat_r1_100m_19_7*1e5,'y-.','LineWidth',2)
plot(t_hat_r1_100m_19,hat_r1_100m_19_9*1e5,'g-.','LineWidth',2)
xlim([9900 10000])
ylim([72.8 73.12]*1e5)
xlabel('Time [s]'); ylabel('Pressure [Pa]')

%% wax = 0.5 mm @ 100m
t_r05_100m = [0 5e3 1e4];
y_r05_100m = [Pressure_COMSOL_waxend(22289,2) Pressure_COMSOL_waxend(29315,2) Pressure_COMSOL_waxend(36341,2)]/1e5;

t_hat_r05_100m_8 = 0:100:10000;
hat_r05_100m_8_8 = Pressure_estimate.estimated_8(:,8);
hat_r05_100m_8_7 = Pressure_estimate.estimated_8(:,7);
hat_r05_100m_8_9 = Pressure_estimate.estimated_8(:,9);

fig100m05mm = figure('Name','COMSOL values waxend 0.5mm','Color','White');
subplot(2,1,1)
plot(t_r05_100m,y_r05_100m,'b','LineWidth',2)
hold on
plot(t_hat_r05_100m_8,hat_r05_100m_8_8,'r','LineWidth',2)
plot(t_hat_r05_100m_8,hat_r05_100m_8_7,'y-.','LineWidth',1.5)
plot(t_hat_r05_100m_8,hat_r05_100m_8_9,'g-.','LineWidth',1.5)
xlabel('Time [s]'); ylabel('Pressure [Bar]')
title('Estimated vs. simulated pressure, 0.5 mm wax deposition at 100 m.')
legend('COMSOL simulation','Estimated at control volume','Estimated left of nearest control volume','Estimated right of nearest control volume','location','southeast')
subplot(2,1,2)
plot(t_r05_100m,y_r05_100m*1e5,'b','LineWidth',2)
hold on
plot(t_hat_r05_100m_8,hat_r05_100m_8_8*1e5,'r','LineWidth',2)
plot(t_hat_r05_100m_8,hat_r05_100m_8_7*1e5,'y-.','LineWidth',2)
plot(t_hat_r05_100m_8,hat_r05_100m_8_9*1e5,'g-.','LineWidth',2)
xlim([9900 10000])
ylim([72.8 73.1]*1e5)
xlabel('Time [s]'); ylabel('Pressure [Pa]')

%% Values from comsol

x_r1_50m_full = Pressure_COMSOL_waxstart(11885:17826,1);
y_r1_50m_full = Pressure_COMSOL_waxstart(11885:17826,2)/1e5;
x_r05_50m_full = Pressure_COMSOL_waxstart(31879:38904,1);
y_r05_50m_full = Pressure_COMSOL_waxstart(31879:38904,2)/1e5;
x_r1_75m_full = Pressure_COMSOL_waxmid(12739:19107,1);
y_r1_75m_full = Pressure_COMSOL_waxmid(12739:19107,2)/1e5;
x_r05_75m_full = Pressure_COMSOL_waxmid(32158:38682,1);
y_r05_75m_full = Pressure_COMSOL_waxmid(32158:38682,2)/1e5;
x_r1_100m_full = Pressure_COMSOL_waxend(11885:17826,1);
y_r1_100m_full = Pressure_COMSOL_waxend(11885:17826,2)/1e5;
x_r05_100m_full = Pressure_COMSOL_waxend(31879:38904,1);
y_r05_100m_full = Pressure_COMSOL_waxend(31879:38904,2)/1e5;

length = [0 7:14:147 150];
y_empty = [75 Pressure_estimate.estimated_0(end,:) 72];
hat_y_r1_50m = [75 Pressure_estimate.estimated_15(end,:) 72];
hat_y_r05_50m = [75 Pressure_estimate.estimated_4(end,:) 72];
hat_y_r1_75m = [75 Pressure_estimate.estimated_17(end,:) 72];
hat_y_r05_75m = [75 Pressure_estimate.estimated_6(end,:) 72];
hat_y_r1_100m = [75 Pressure_estimate.estimated_19(end,:) 72];
hat_y_r05_100m = [75 Pressure_estimate.estimated_8(end,:) 72];

fig_compare50 = figure('Name','COMSOL profile vs MATLAB profile','Color','White');
subplot(3,1,1)
plot(x_r1_50m_full,y_r1_50m_full,'b','LineWidth',2)
hold on
plot(length,hat_y_r1_50m,'r','LineWidth',2)
plot(length,y_empty,'y-.','LineWidth',1)
xlabel('Length [m]'); ylabel('Pressure [Bar]')
title('Estimated vs. simulated pressure, wax deposition at 50 m. Time = 10000 seconds')
legend('Simulated in COMSOL','Estimated with 1mm wax in control volume','Estimated with no wax')
subplot(3,1,2)
plot(x_r05_50m_full,y_r05_50m_full,'b','LineWidth',2)
hold on
plot(length,hat_y_r05_50m,'k','LineWidth',2)
plot(length,y_empty,'g-.','LineWidth',1)
xlabel('Length [m]'); ylabel('Pressure [Bar]')
legend('Simulated in COMSOL','Estimated with 0.5mm wax in control volume','Estimated with no wax')
subplot(3,1,3)
plot(length,Pressure_COMSOL_waxstart(11885:495:17826,2)'-hat_y_r1_50m*1e5,'r-.','LineWidth',1)
hold on
plot(length,Pressure_COMSOL_waxstart(11885:495:17826,2)'-[75 Pressure_estimate.estimated_0(end,:) 72]*1e5,'y-.','LineWidth',1)
plot(length,Pressure_COMSOL_waxstart(31879:585:38904,2)'-hat_y_r05_50m*1e5,'k','LineWidth',2)
plot(length,Pressure_COMSOL_waxstart(31879:585:38904,2)'-[75 Pressure_estimate.estimated_0(end,:) 72]*1e5,'g-.','LineWidth',1)
ylim([-0.8 0.8]*1e5)
xlabel('Length [m]'); ylabel('Pressure [Pa]')
title('Estimated vs. simulated pressure, error')
legend('Error 1 mm wax in control volume','Error between empty pipe and simulated wax 1 mm','Error 0.5 mm wax in control volume','Error between empty pipe and simulated wax 0.5 mm','location','southoutside')

fig_compare75 = figure('Name','COMSOL profile vs MATLAB profile','Color','White');
subplot(3,1,1)
plot(x_r1_75m_full,y_r1_75m_full,'b','LineWidth',2)
hold on
plot(length,hat_y_r1_75m,'r','LineWidth',2)
plot(length,y_empty,'y-.','LineWidth',1)
xlabel('Length [m]'); ylabel('Pressure [Bar]')
title('Estimated vs. simulated pressure, wax deposition at 75 m. Time = 10000 seconds')
legend('Simulated in COMSOL','Estimated with 1mm wax in control volume','Estimated with no wax')
subplot(3,1,2)
plot(x_r05_75m_full,y_r05_75m_full,'b','LineWidth',2)
hold on
plot(length,hat_y_r05_75m,'k','LineWidth',2)
plot(length,y_empty,'g-.','LineWidth',1)
xlabel('Length [m]'); ylabel('Pressure [Bar]')
legend('Simulated in COMSOL','Estimated with 0.5mm wax in control volume','Estimated with no wax')
subplot(3,1,3)
plot(length,Pressure_COMSOL_waxmid(12739:530:19107,2)'-hat_y_r1_75m*1e5,'r-.','LineWidth',2)
hold on
plot(length,Pressure_COMSOL_waxmid(12739:530:19107,2)'-[75 Pressure_estimate.estimated_0(end,:) 72]*1e5,'y-.','LineWidth',1)
plot(length,Pressure_COMSOL_waxmid(32158:543:38682,2)'-hat_y_r05_75m*1e5,'k','LineWidth',2)
plot(length,Pressure_COMSOL_waxmid(32158:543:38682,2)'-[75 Pressure_estimate.estimated_0(end,:) 72]*1e5,'g-.','LineWidth',1)
ylim([-0.8 0.8]*1e5)
xlabel('Length [m]'); ylabel('Pressure [Pa]')
title('Estimated vs. simulated pressure, error')
legend('Error 1 mm wax in control volume','Error between empty pipe and simulated wax 1 mm','Error 0.5 mm wax in control volume','Error between empty pipe and simulated wax 0.5 mm','location','southoutside')


fig_compare100 = figure('Name','COMSOL profile vs MATLAB profile','Color','White');
subplot(3,1,1)
plot(x_r1_100m_full,y_r1_100m_full,'b','LineWidth',2)
hold on
plot(length,hat_y_r1_100m,'r','LineWidth',2)
plot(length,y_empty,'y-.','LineWidth',1)
xlabel('Length [m]'); ylabel('Pressure [Bar]')
title('Estimated vs. simulated pressure, wax deposition at 100 m. Time = 10000 seconds')
legend('Simulated in COMSOL','Estimated with 1mm wax in control volume','Estimated with no wax')
subplot(3,1,2)
plot(x_r05_100m_full,y_r05_100m_full,'b','LineWidth',2)
hold on
plot(length,hat_y_r05_100m,'k','LineWidth',2)
plot(length,y_empty,'g-.','LineWidth',1)
xlabel('Length [m]'); ylabel('Pressure [Bar]')
legend('Simulated in COMSOL','Estimated with 0.5mm wax in control volume','Estimated with no wax')
subplot(3,1,3)
grid on
plot(length,Pressure_COMSOL_waxend(11885:495:17826,2)'-hat_y_r1_100m*1e5,'r','LineWidth',2)
hold on
plot(length,Pressure_COMSOL_waxend(11885:495:17826,2)'-[75 Pressure_estimate.estimated_0(end,:) 72]*1e5,'y-.','LineWidth',1)
plot(length,Pressure_COMSOL_waxend(31879:585:38904,2)'-hat_y_r05_75m*1e5,'k','LineWidth',2)
plot(length,Pressure_COMSOL_waxend(31879:585:38904,2)'-[75 Pressure_estimate.estimated_0(end,:) 72]*1e5,'g-.','LineWidth',1)
ylim([-0.8 1]*1e5)
xlabel('Length [m]'); ylabel('Pressure [Pa]')
title('Estimated vs. simulated pressure, error')
legend('Error 1 mm wax in control volume','Error between empty pipe and simulated wax 1 mm','Error 0.5 mm wax in control volume','Error between empty pipe and simulated wax 0.5 mm','location','southoutside')

%% Saving plots

saveas(fig50m1mm,'plots/plot50m1mm','epsc')
saveas(fig50m05mm,'plots/plot50m05mm','epsc')
saveas(fig75m1mm,'plots/plot75m1mm','epsc')
saveas(fig75m05mm,'plots/plot75m05mm','epsc')
saveas(fig100m1mm,'plots/plot100m1mm','epsc')
saveas(fig100m05mm,'plots/plot100m05mm','epsc')
saveas(fig_compare50,'plots/plotcompare50','epsc')
saveas(fig_compare75,'plots/plotcompare75','epsc')
saveas(fig_compare100,'plots/plotcompare100','epsc')
